# Copyright 2017 Google, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import tempfile

from google.cloud import storage
import pytest

import storage_disable_requester_pays
import storage_download_file_requester_pays
import storage_enable_requester_pays
import storage_get_requester_pays_status


# We use a different bucket from other tests.
# The service account for the test needs to have Billing Project Manager role
# in order to make changes on buckets with requester pays enabled.
BUCKET = os.environ["REQUESTER_PAYS_TEST_BUCKET"]
PROJECT = os.environ["GOOGLE_CLOUD_PROJECT"]


def test_enable_requester_pays(capsys):
    storage_enable_requester_pays.enable_requester_pays(BUCKET)
    out, _ = capsys.readouterr()
    assert f"Requester Pays has been enabled for {BUCKET}" in out


def test_disable_requester_pays(capsys):
    storage_disable_requester_pays.disable_requester_pays(BUCKET)
    out, _ = capsys.readouterr()
    assert f"Requester Pays has been disabled for {BUCKET}" in out


def test_get_requester_pays_status(capsys):
    storage_get_requester_pays_status.get_requester_pays_status(BUCKET)
    out, _ = capsys.readouterr()
    assert f"Requester Pays is disabled for {BUCKET}" in out


@pytest.fixture
def test_blob():
    """Provides a pre-existing blob in the test bucket."""
    bucket = storage.Client().bucket(BUCKET)
    blob = bucket.blob("storage_snippets_test_sigil")
    blob.upload_from_string("Hello, is it me you're looking for?")
    return blob


def test_download_file_requester_pays(test_blob, capsys):
    with tempfile.NamedTemporaryFile() as dest_file:
        storage_download_file_requester_pays.download_file_requester_pays(
            BUCKET, PROJECT, test_blob.name, dest_file.name
        )

        assert dest_file.read()
